@@ -110,7 +110,7 @@ if(defined($params{input_for_database})){
   printf STDERR "number of libraries: $nlibs\n";
   printf STDERR "libs: @input_libs\n";
 }else{
-  die "specify input_fastq in ec.spec\n";
+  die "specify input_for_database in ec.spec\n";
 }
 
 if(defined($params{estimated_genome_size})){
